# Guide

Welcome to bionty! 👋

## Resources

Lookup & curate metadata based on scientific standards.

- Gene: [Ensembl](https://ensembl.org/), [NCBI Gene](https://www.ncbi.nlm.nih.gov/gene/), [HGNC](https://www.genenames.org/), [MGI](http://www.informatics.jax.org/)
- Protein: [Uniprot](https://www.uniprot.org/)
- Species: [NCBI Taxonomy](https://www.ncbi.nlm.nih.gov/taxonomy/), [Ensembl Species](https://useast.ensembl.org/info/about/species.html)
- Cell type: [Cell Ontology](https://obophenotype.github.io/cell-ontology/)
- Cell marker: [CellMarker](http://xteam.xbio.top/CellMarker)
- Tissue: [Uberon](http://obophenotype.github.io/uberon/)
- Disease: [Mondo](https://mondo.monarchinitiative.org/)
- Phenotype: [HPO](https://hpo.jax.org/app/)

## Getting started

Install:

```
pip install bionty
```

Get started with the following walk-through:

- {doc}`curate`
- {doc}`lookup`
- {doc}`concepts`

Explore additional entities:

- {doc}`ontology`

See [bionty-assets](https://lamin.ai/docs/bionty-assets) for the curation of underlying assets.

```{toctree}
:maxdepth: 2
:hidden:

curate
lookup
ontology
concepts
```
